Package: frailtypack
Title: Shared, Joint (Generalized) Frailty Models; Surrogate Endpoints
Version: 3.8.0
Date: 2025-11-20
Authors@R: c(
    person("Virginie", "Rondeau", , "virginie.rondeau@u-bordeaux.fr", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0001-7109-4831")),
    person("Juan R.", "Gonzalez", role = "aut"),
    person("Yassin", "Mazroui", role = "aut"),
    person("Audrey", "Mauguen", role = "aut"),
    person("Amadou", "Diakite", role = "aut"),
    person("Alexandre", "Laurent", role = "aut"),
    person("Myriam", "Lopez", role = "aut"),
    person("Agnieszka", "Krol", role = "aut"),
    person("Casimir L.", "Sofeu", role = "aut"),
    person("Julien", "Dumerc", role = "aut"),
    person("Denis", "Rustand", role = "aut"),
    person("Jocelyn", "Chauvet", role = "aut"),
    person("Quentin", "Le Coent", role = "aut"),
    person("Romain", "Pierlot", role = "aut"),
    person("Lacey", "Etzkorn", role = "aut"),
    person("Derek", "Dinart", role = "aut"),
    person("Adrien", "Orué", role = "aut"),
    person("Ayoub", "Bifenzi", role = "aut"),
    person("Viviane", "Philipps", role = "aut"),
    person("David", "Hill", role = "cph"),
    person("John", "Burkardt", role = "cph"),
    person("Alan", "Genz", role = "cph"),
    person("Ashwith J.", "Rego", role = "cph")
  )
Author: Virginie Rondeau [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-7109-4831>),
  Juan R. Gonzalez [aut],
  Yassin Mazroui [aut],
  Audrey Mauguen [aut],
  Amadou Diakite [aut],
  Alexandre Laurent [aut],
  Myriam Lopez [aut],
  Agnieszka Krol [aut],
  Casimir L. Sofeu [aut],
  Julien Dumerc [aut],
  Denis Rustand [aut],
  Jocelyn Chauvet [aut],
  Quentin Le Coent [aut],
  Romain Pierlot [aut],
  Lacey Etzkorn [aut],
  Derek Dinart [aut],
  Adrien Orué [aut],
  Ayoub Bifenzi [aut],
  Viviane Philipps [aut],
  David Hill [cph],
  John Burkardt [cph],
  Alan Genz [cph],
  Ashwith J. Rego [cph]
Maintainer: Virginie Rondeau <virginie.rondeau@u-bordeaux.fr>
Description: The following several classes of frailty models using a
    penalized likelihood estimation on the hazard function but also a
    parametric estimation can be fit using this R package: 1) A shared
    frailty model (with gamma or log-normal frailty distribution) and Cox
    proportional hazard model. Clustered and recurrent survival times can
    be studied.  2) Additive frailty models for proportional hazard models
    with two correlated random effects (intercept random effect with
    random slope).  3) Nested frailty models for hierarchically clustered
    data (with 2 levels of clustering) by including two iid gamma random
    effects.  4) Joint frailty models in the context of the joint
    modelling for recurrent events with terminal event for clustered data
    or not. A joint frailty model for two semi-competing risks and
    clustered data is also proposed.  5) Joint general frailty models in
    the context of the joint modelling for recurrent events with terminal
    event data with two independent frailty terms.  6) Joint Nested
    frailty models in the context of the joint modelling for recurrent
    events with terminal event, for hierarchically clustered data (with
    two levels of clustering) by including two iid gamma random effects.
    7) Multivariate joint frailty models for two types of recurrent events
    and a terminal event.  8) Joint models for longitudinal data and a
    terminal event.  9) Trivariate joint models for longitudinal data,
    recurrent events and a terminal event.  10) Joint frailty models for
    the validation of surrogate endpoints in multiple randomized clinical
    trials with failure-time and/or longitudinal endpoints with the
    possibility to use a mediation analysis model.  11) Conditional and
    Marginal two-part joint models for longitudinal semicontinuous data
    and a terminal event.  12) Joint frailty-copula models for the
    validation of surrogate endpoints in multiple randomized clinical
    trials with failure-time endpoints.  13) Generalized shared and joint
    frailty models for recurrent and terminal events. Proportional hazards
    (PH), additive hazard (AH), proportional odds (PO) and probit models
    are available in a fully parametric framework. For PH and AH models,
    it is possible to consider type-varying coefficients and flexible
    semiparametric hazard function.  Prediction values are available (for
    a terminal event or for a new recurrent event). Left-truncated (not
    for Joint model), right-censored data, interval-censored data (only
    for Cox proportional hazard and shared frailty model) and strata are
    allowed. In each model, the random effects have the gamma or normal
    distribution. Now, you can also consider time-varying covariates
    effects in Cox, shared and joint frailty models (1-5). The package
    includes concordance measures for Cox proportional hazards models and
    for shared frailty models.  14) Competing Joint Frailty Model: A
    single type of recurrent event and two terminal events.  15) functions 
    to compute power and sample size for four Gamma-frailty-based designs: 
    Shared Frailty Models, Nested Frailty Models, Joint Frailty Models, and 
    General Joint Frailty Models. Each design includes two primary functions: a 
    power function, which computes power given a specified sample size; 
    and a sample size function, which computes the required sample size to achieve 
    a specified power. 16) Weibull Illness-Death model with or without shared frailty
    between transitions. Left-truncated and right-censored data are allowed. 
    17) Weibull Competing risks model with or without shared frailty between the 
    transitions. Left-truncated and right-censored data are allowed. Moreover, the package can be used with its shiny
    application, in a local mode or by following the link below.
License: GPL (>= 2.0)
URL:
        https://virginie1rondeau.wixsite.com/virginierondeau/software-frailtypack
        https://frailtypack-pkg.shinyapps.io/shiny_frailtypack/
Depends: boot, doBy, MASS, R (>= 3.5.0), survC1, survival
Imports: graphics, matrixcalc, nlme, rootSolve, shiny, splines,
        statmod, stats, utils, dplyr, marqLevAlg, tidyr,
Suggests: knitr, timereg, rmarkdown
VignetteBuilder: knitr
Date/Publication: 2025-11-22 23:30:02 UTC
Encoding: UTF-8
LazyLoad: no
NeedsCompilation: yes
Packaged: 2025-11-20 13:30:36 UTC; ab25
Repository: CRAN
RoxygenNote: 7.3.3
Built: R 4.6.0; aarch64-apple-darwin23; 2026-04-25 14:01:25 UTC; unix
Archs: frailtypack.so.dSYM
