# Generated by roxygen2: do not edit by hand

S3method(lines,frailtyPenal)
S3method(plot,Diffepoce)
S3method(plot,additivePenal)
S3method(plot,epoce)
S3method(plot,frailtyCmprsk)
S3method(plot,frailtyIllnessDeath)
S3method(plot,frailtyPenal)
S3method(plot,jointNestedPenal)
S3method(plot,jointPenal)
S3method(plot,jointRecCompet)
S3method(plot,jointSurroMed)
S3method(plot,jointSurroPenal)
S3method(plot,jointSurroPenalloocv)
S3method(plot,longiPenal)
S3method(plot,multivPenal)
S3method(plot,nestedPenal)
S3method(plot,predFrailty)
S3method(plot,predJoint)
S3method(plot,predJointNested)
S3method(plot,predLongi)
S3method(plot,trivPenal)
S3method(plot,trivPenalNL)
S3method(predict,jointSurroPenal)
S3method(print,Cmeasures)
S3method(print,Diffepoce)
S3method(print,additivePenal)
S3method(print,epoce)
S3method(print,frailtyCmprsk)
S3method(print,frailtyDesign)
S3method(print,frailtyIllnessDeath)
S3method(print,frailtyPenal)
S3method(print,jointNestedPenal)
S3method(print,jointPenal)
S3method(print,jointRecCompet)
S3method(print,jointSurroPenal)
S3method(print,longiPenal)
S3method(print,multivPenal)
S3method(print,nestedPenal)
S3method(print,predFrailty)
S3method(print,predJoint)
S3method(print,predJointNested)
S3method(print,predLongi)
S3method(print,trivPenal)
S3method(print,trivPenalNL)
S3method(summary,additivePenal)
S3method(summary,frailtyCmprsk)
S3method(summary,frailtyDesign)
S3method(summary,frailtyIllnessDeath)
S3method(summary,frailtyPenal)
S3method(summary,jointNestedPenal)
S3method(summary,jointPenal)
S3method(summary,jointRecCompet)
S3method(summary,jointSurroMed)
S3method(summary,jointSurroPenal)
S3method(summary,jointSurroPenalSimul)
S3method(summary,longiPenal)
S3method(summary,multivPenal)
S3method(summary,nestedPenal)
S3method(summary,trivPenal)
S3method(summary,trivPenalNL)
export(Cmeasures)
export(Diffepoce)
export(GJFM.power)
export(GJFM.ssize)
export(GenfrailtyPenal)
export(JFM.power)
export(JFM.ssize)
export(NFM.power)
export(NFM.ssize)
export(SFM.power)
export(SFM.ssize)
export(SurvIC)
export(additivePenal)
export(cluster)
export(epoce)
export(event2)
export(frailtyCmprsk)
export(frailtyIllnessDeath)
export(frailtyPenal)
export(hazard)
export(jointRecCompet)
export(jointSurrCopSimul)
export(jointSurrSimul)
export(jointSurroCopPenal)
export(jointSurroPenal)
export(jointSurroPenalSimul)
export(jointSurroTKendall)
export(longiPenal)
export(loocv)
export(multivPenal)
export(num.id)
export(plotTreatPredJointSurro)
export(prediction)
export(runShiny)
export(simulatejointRecCompet)
export(slope)
export(ste)
export(subcluster)
export(survival)
export(terminal)
export(timedep)
export(trivPenal)
export(trivPenalNL)
export(wts)
import(MASS)
import(boot)
import(doBy)
import(graphics)
import(marqLevAlg)
import(nlme)
import(survC1)
import(survival)
importFrom(doBy,orderBy)
importFrom(dplyr,"%>%")
importFrom(dplyr,filter)
importFrom(graphics,abline)
importFrom(graphics,boxplot)
importFrom(graphics,curve)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,matlines)
importFrom(graphics,matplot)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,points)
importFrom(graphics,rect)
importFrom(graphics,segments)
importFrom(matrixcalc,is.positive.definite)
importFrom(matrixcalc,is.square.matrix)
importFrom(nlme,lme)
importFrom(rootSolve,uniroot.all)
importFrom(splines,splineDesign)
importFrom(statmod,gauss.quad)
importFrom(stats,.getXlevels)
importFrom(stats,aggregate)
importFrom(stats,as.formula)
importFrom(stats,ave)
importFrom(stats,complete.cases)
importFrom(stats,contrasts)
importFrom(stats,delete.response)
importFrom(stats,drop.terms)
importFrom(stats,dweibull)
importFrom(stats,get_all_vars)
importFrom(stats,is.empty.model)
importFrom(stats,median)
importFrom(stats,model.extract)
importFrom(stats,model.frame)
importFrom(stats,model.matrix)
importFrom(stats,model.response)
importFrom(stats,na.pass)
importFrom(stats,optimize)
importFrom(stats,pchisq)
importFrom(stats,pnorm)
importFrom(stats,pweibull)
importFrom(stats,qchisq)
importFrom(stats,qnorm)
importFrom(stats,quantile)
importFrom(stats,qweibull)
importFrom(stats,rbinom)
importFrom(stats,reformulate)
importFrom(stats,rexp)
importFrom(stats,rgamma)
importFrom(stats,rnorm)
importFrom(stats,rpois)
importFrom(stats,runif)
importFrom(stats,rweibull)
importFrom(stats,sd)
importFrom(stats,terms)
importFrom(stats,uniroot)
importFrom(stats,update)
importFrom(stats,var)
importFrom(tidyr,drop_na)
importFrom(utils,flush.console)
importFrom(utils,type.convert)
useDynLib("frailtypack", .registration = TRUE, .fixes = "C_")
