---
output:
  html_document: default
  pdf_document: default
---
<!--
%\VignetteIndexEntry{Package summary}
%\VignetteEngine{knitr::rmarkdown}
%\usepackage[UTF-8]{inputenc}
-->

|                                                 |                  Cox                  |                 Shared                |                 Nested                |                Additive               |Joint standard *(Bivariate: 1 RE + 1 TE)*| Joint cluster *(Bivariate: 1 RE + 1 TE)*|Joint general *(Bivariate: 1 RE + 1 TE)*|Joint nested *(Bivariate: 1 RE + 1 TE)*|Joint longitudinal *(Bivariate:  1 LO + 1 TE)*|Joint trivariate *(Trivariate: 1 LO + 1 RE + 1 TE)*|Joint non linear trivariate *(Trivariate: 1 LO + 1 RE + 1 TE)*|Joint Multivariate *(Trivariate: 2 RE + 1 TE)*|Joint surrogate *(Bivariate: 2 TE)*| Conditional two-part joint  *(Trivariate: 2 LO 1 TE)*| Marginal two-part joint  *(Trivariate: 2 LO 1 TE)*| Shared Frailty GSM | Joint Frailty GSM *(Bivariate: 1 RE + 1 TE)*| Illness-Death with/without shared Frailty | Competing risks with/without shared Frailty |   |
|:------------------------------------------------|:-------------------------------------:|:-------------------------------------:|:-------------------------------------:|:-------------------------------------:|:--------------------------------------:|:--------------------------------------:|:-------------------------------------:|:------------------------------------:|:------------------------------------------:|:-------------------------------------:|:-------------------------------------:|:-------------------------------------:|:-------------------------------------:|:-------------------------------------:|:-------------------------------------:|:-------------------------------------:|:-------------------------------------:|:-------------------------------------:|:-------------------------------------:|
|`Available  options `                       |                                       |                                       |                                       |                                       |                                        |                                        |                                       |                                      |                                            |                                       |                                       |                                       |                                       |                                       |                                       |                                       |                                       |                                       |                                       |
| Family (PHM, AHM, POM, PROM)                    |                                       |                                       |                                       |                                       |                                        |                                        |                                       |                                      |                                            |                                       |                                       |                                       |                                       |                                       |                                       |   <img src="blue_x.png"  title="GenfrailtyPenal(Surv(futime,status)~trt+cluster(id),data=adult.retino,hazard='parametric',family='PH')"/>              |       <img src="blue_x.png"  title="GenfrailtyPenal(Surv(t.start,t.stop,event)~cluster(id)+terminal(death)+sex+dukes+chemo,~sex+dukes+chemo,data=readmission,recurrentAG=TRUE,hazard='parametric',family=c('PH','PH'))"/>          |                                       |                                       |
| Gamma distribution                              |                                       | <img src="blue_x.png"  title="frailtyPenal(Surv(time,status)~cluster(id)+sex+age,n.knots=12,kappa=10000,data=kidney)"/>                       | <img src="blue_x.png"  title="frailtyPenal(Surv(t1,t2,event)~cluster(group)+subcluster(subgroup)+cov1+cov2,data=dataNested,n.knots=8,kappa=50000)"/>                       |                                       |  <img src="blue_x.png"  title="frailtyPenal(Surv(time,event)~cluster(id)+sex+dukes+charlson+terminal(death),formula.terminalEvent=~sex+dukes+charlson,data=readmission,n.knots=14,kappa=c(9.55e+9,1.41e+12),recurrentAG=FALSE) "/>                       |  <img src="blue_x.png"  title="frailtyPenal(Surv(time,event)~cluster(group)+num.id(id)+dukes+charlson+sex+chemo+terminal(death),formula.terminalEvent=~dukes+charlson+sex+chemo,data=readmission2,recurrentAG=FALSE,n.knots=8,kappa=c(1.e+10,1.e+10),Alpha=&quot;None&quot;)"/>                       | <img src="blue_x.png"  title="frailtyPenal(Surv(time,event)~cluster(id)+dukes+charlson+sex+chemo+terminal(death),formula.terminalEvent=~dukes+charlson+sex+chemo,data=readmission,jointGeneral=TRUE,n.knots=8,kappa=c(2.11e+08,9.53e+11))"/>                       | <img src="blue_x.png"  title="frailtyPenal(formula=Surv(time,event)~subcluster(id)+cluster(group)+dukes+terminal(death),formula.terminalEvent=~dukes,data=readmissionNested,recurrentAG=FALSE,n.knots=8,kappa=c(9.55e+9,1.41e+12),initialize=TRUE,init.Alpha=1.091,Ksi=&quot;None&quot;)"/>                      |                                       |                                            |                                       |                                       |                                       |                                       |                                       |   <img src="blue_x.png"  title="GenfrailtyPenal(Surv(futime,status)~trt+cluster(id),data=adult.retino,RandDist='Gamma',hazard='parametric',family='AH')"/>              |       <img src="blue_x.png"  title="GenfrailtyPenal(Surv(t.start,t.stop,event)~cluster(id)+terminal(death)+sex+dukes+chemo,~sex+dukes+chemo,data=readmission,RandDist='Gamma',recurrentAG=TRUE,hazard='parametric',family=c('AH','AH'))"/>          | <img src="blue_x.png" title="frailtyIllnessDeath(formula = Surv(r,dementia) ~ gender+certif, formula.terminalEvent = Surv(e,t,death) ~ gender+certif  , data=IDPaq1000,print.info = FALSE)"/> | <img src="blue_x.png" title="frailtyCmprsk(formula = Surv(observed_time,Status) ~ cluster(group)+Sex,formula2 = ~ Sex  ,data=CPRSKbmtcrr,print.info = FALSE,maxit=100)"/> |                    
| Log-Normal distribution                         |                                       | <img src="blue_x.png"  title="frailtyPenal(Surv(time,status)~cluster(id)+sex+age,n.knots=12,kappa=10000,data=kidney,RandDist=&quot;LogN&quot;)"/>                       |                                       | <img src="blue_x.png"  title="additivePenal(Surv(t1,t2,event)~cluster(group)+var1+slope(var1),correlation=TRUE,data=dataAdditive,n.knots=8,kappa=10000)"/>                       |  <img src="blue_x.png"  title="frailtyPenal(Surv(t.start,t.stop,event)~cluster(id)+sex+dukes+charlson+terminal(death),formula.terminalEvent=~sex+dukes+charlson,data=readmission,n.knots=10,kappa=c(9.55e9,1.41e12),recurrentAG=TRUE,RandDist=&quot;LogN&quot;) "/>                       |                                        |                                       |                                      | <img src="blue_x.png"  title="longiPenal(Surv(time1,state)~age+treatment+who.PS+prev.resection,tumor.size~year*treatment+age+who.PS,colorectalSurv,data.Longi=colorectalLongi,random=c(&quot;1&quot;,&quot;year&quot;),id=&quot;id&quot;,link=&quot;Random-effects&quot;,left.censoring=-3.33,n.knots=7,kappa=2)"/>                            | <img src="blue_x.png"  title="trivPenal(Surv(time0,time1,new.lesions)~cluster(id)+age+treatment+who.PS+terminal(state),formula.terminalEvent=~age+treatment+who.PS+prev.resection,tumor.size~year*treatment+age+who.PS,data=colorectal,data.Longi=colorectalLongi,random=c(&quot;1&quot;,&quot;year&quot;),id=&quot;id&quot;,link=&quot;Random-effects&quot;,left.censoring=-3.33,recurrentAG=TRUE,n.knots=6,kappa=c(0.01,2),method.GH=&quot;Standard&quot;,n.nodes=7)"/>                       | <img src="blue_x.png"  title="trivPenalNL(Surv(time0,time1,new.lesions)~cluster(id)+age+treatment+terminal(state),formula.terminalEvent=~age+treatment,biomarker=&quot;tumor.size&quot;,formula.KG~1,formula.KD~treatment,dose=&quot;dose&quot;,time.biomarker=&quot;year&quot;,data=colorectal,data.Longi=colorectalLongi,random=&quot;KG&quot;,id=&quot;id&quot;,recurrentAG=TRUE,n.knots=5,kappa=c(0.01,2),method.GH=&quot;Pseudo-adaptive&quot;)"/>                                      | <img src="blue_x.png"  title="multivPenal(Surv(TIMEGAP,INDICREC)~cluster(PATIENT)+v1+v2+event2(INDICMETA)+terminal(INDICDEATH),formula.Event2=~v1+v2+v3,formula.terminalEvent=~v1,data=dataMultiv,n.knots=c(8,8,8),kappa=c(1,1,1),initialize=FALSE)"/>                       |  <img src="blue_x.png"  title="#-- Surrogacy evaluation based on ganerated data with a combination of Monte Carlo and classical Gaussian Hermite integration : jointSurroPenal(data=data.sim,int.method=2,nb.mc=300,nb.gh=20)"/>                                        |                                      |                                    |       |    |    |    |  
| Left-truncation                                 | <img src="blue_x.png"  title="frailtyPenal(formula=Surv(t1,t2,event)~cov1+cov2,data=dataNested,recurrentAG=FALSE,cross.validation=TRUE,n.knots=10,kappa=10000)"/>                       | <img src="blue_x.png"  title="frailtyPenal(Surv(t1,t2,event) ~ cluster(group), data = dataNested, n.knots = 10, kappa = 10000, cross.validation = TRUE, recurrentAG = FALSE)"/>                       | <img src="blue_x.png"  title="frailtyPenal(Surv(t1,t2,event)~cluster(group)+subcluster(subgroup)+cov1+cov2,data=dataNested,n.knots=8,kappa=50000)"/>                       |                                       |                                        |                                        |                                       |                                      |                                            |                                       |                                       |                                       |                                       |                                       |                                      | <img src="blue_x.png"  title="GenfrailtyPenal(Surv(t1,t2,event)~cluster(group), data=dataNested, hazard='parametric', family='PH', recurrentAG=FALSE)"/> |    |<img src="blue_x.png" title="frailtyIllnessDeath(formula = Surv(r,dementia) ~ gender+certif, formula.terminalEvent = Surv(e,t,death) ~ gender+certif  , data=IDPaq1000,print.info = FALSE)"/>| <img src="blue_x.png" title="frailtyCmprsk(formula = Surv(Age,observed_time,Status) ~ Sex,formula2 = ~ Sex,data=CPRSKbmtcrr,print.info = FALSE,maxit=100)"/>  |  
| Interval Censoring                              | <img src="blue_x.png"  title="frailtyPenal(SurvIC(left,right,event) ~ treatment,n.knots=8,kappa=10000,data=bcos)"/>                       | <img src="blue_x.png"  title="frailtyPenal(SurvIC(left,right,event) ~ cluster(group)+treatment,n.knots=8,kappa=10000,data=bcos)"/>                       |                                       |                                       |  ![](orange_x.png)                     |  ![](orange_x.png)                     |                                       |                                      |                                            |                                       |                                       |                                       |                                       |                                       |                                      |  <img src="blue_x.png"  title="GenfrailtyPenal(SurvIC(left,right,event)~cluster(group)+treatment, data=bcos, hazard='Splines', family='PH', n.knots=4, kappa=10000)"/>  |    |    |    |  
| Two strata                                      | <img src="blue_x.png"  title="frailtyPenal(Surv(time,event) ~ dukes+strata(sex),n.knots=10,kappa=c(10000,10000),data=readmission)"/>                       | <img src="blue_x.png"  title="frailtyPenal(Surv(time,event)~cluster(id)+dukes+strata(sex),n.knots=10,kappa=c(10000,10000),data=readmission)"/>                       | <img src="blue_x.png"  title="frailtyPenal(Surv(t1,t2,event)~cluster(group)+subcluster(subgroup)+cov1+strata(cov2),data=dataNested,n.knots=8,kappa=c(50000,50000))"/>                       | <img src="blue_x.png"  title="additivePenal(Surv(t1,t2,event)~cluster(group)+var1+strata(var2)+slope(var1),cross.validation=TRUE,correlation=FALSE,data=dataAdditive,n.knots=10,kappa=c(1,1))"/>                       | <img src="blue_x.png"  title="frailtyPenal(Surv(time,event)~cluster(id)+dukes+charlson+strata(sex)+chemo+terminal(death),formula.terminalEvent=~dukes+charlson+sex+chemo,data=readmission,n.knots=8,kappa=c(2.11e+08,2.11e+08,9.53e+11))"/>                                     |                                        |                                       |                                      |                                            |                                       |                                       |                                      |                                       |                                       |                                       |   <img src="blue_x.png"  title="GenfrailtyPenal(Surv(time,event)~cluster(id)+dukes+strata(sex), hazard='Splines', family='PH', n.knots=10, kappa=c(10000,10000), data=readmission)"/>      |  <img src="blue_x.png"  title="GenfrailtyPenal(Surv(time,event)~cluster(id)+dukes+charlson+strata(sex)+chemo+terminal(death), formula.terminalEvent=~dukes+charlson+sex+chemo, data=readmission, hazard='parametric', family=c('probit','probit'))"/>  |     |    | 
| More strata (max=6)                             | <img src="blue_x.png"/>               | <img src="blue_x.png"/>               |                                       |                                       |  <img src="blue_x.png"/>                       |                                        |                                       |                                      |                                            |                                       |                                       |                                       |                                       |                                      |   <img src="blue_x.png"/>   |  <img src="blue_x.png"/>  |  
| Time-dependant covariates                       | <img src="blue_x.png"/>               | <img src="blue_x.png"/>               |                                       |                                       |  <img src="blue_x.png"/>                       |  <img src="blue_x.png"/>                       |                                       |                                      |                                            |                                       |                                       |                                       |                                       |  <img src="blue_x.png"/>                                     | <img src="blue_x.png"/>                                       |    <img src="blue_x.png"  title="GenfrailtyPenal(Surv(futime,status)~cluster(id)+timedep(trt),data=adult.retino,family='AH',hazard='Splines',n.knots=8,kappa=10^10,betaknots=1,betaorder=2)"/>    |  <img src="blue_x.png"  title="GenfrailtyPenal(formula=Surv(t.start,t.stop,event)~cluster(id)+terminal(death)+sex+dukes+timedep(chemo),formula.terminalEvent=~sex+dukes+timedep(chemo),data=readmission,recurrentAG=TRUE,hazard='Splines',n.knots=5,kappa=c(100,100),betaknots=1,betaorder=3,family=c('PH','PH'))"/>  |    |    |     |     |  
| Calendar timescale                              | <img src="blue_x.png"  title="frailtyPenal(Surv(t.start,t.stop,event)~sex+dukes+charlson,data=readmission,n.knots=6,kappa=1e5,recurrentAG=TRUE)"/>            | <img src="blue_x.png"  title="frailtyPenal(Surv(t.start,t.stop,event)~cluster(id)+sex+dukes+charlson,data=readmission,n.knots=6,kappa=1e5,recurrentAG=TRUE)"/>                       | <img src="blue_x.png"  title="frailtyPenal(Surv(t1,t2,event)~cluster(group)+subcluster(subgroup)+cov1+cov2,data=dataNested,n.knots=8,kappa=50000)"/>                       |                                       |  <img src="blue_x.png"  title="frailtyPenal(Surv(t.start,t.stop,event)~cluster(id)+sex+dukes+charlson+terminal(death),formula.terminalEvent=~sex+dukes+charlson,data=readmission,n.knots=10,kappa=c(9.55e9,1.41e12),recurrentAG=TRUE)"/>                       |                                        |                                       | <img src="blue_x.png"  title="frailtyPenal(formula=Surv(t.start,t.stop,event)~subcluster(id)+cluster(group)+dukes+terminal(death),formula.terminalEvent=~dukes,data=readmissionNested,recurrentAG=TRUE,n.knots=8,kappa=c(9.55e+9,1.41e+12),initialize=TRUE)"/>                      |                                            | <img src="blue_x.png"  title="trivPenal(Surv(time0,time1,new.lesions)~cluster(id)+age+treatment+who.PS+terminal(state),formula.terminalEvent=~age+treatment+who.PS+prev.resection,tumor.size~year*treatment+age+who.PS,data=colorectal,data.Longi=colorectalLongi,random=c(&quot;1&quot;,&quot;year&quot;),id=&quot;id&quot;,link=&quot;Random-effects&quot;,left.censoring=-3.33,recurrentAG=TRUE,n.knots=6,kappa=c(0.01,2),method.GH=&quot;Standard&quot;,n.nodes=7)"/>                       |  <img src="blue_x.png"  title="trivPenalNL(Surv(time0,time1,new.lesions)~cluster(id)+age+treatment+terminal(state),formula.terminalEvent=~age+treatment,biomarker=&quot;tumor.size&quot;,formula.KG~1,formula.KD~treatment,dose=&quot;dose&quot;,time.biomarker=&quot;year&quot;,data=colorectal,data.Longi=colorectalLongi,random=&quot;KG&quot;,id=&quot;id&quot;,recurrentAG=TRUE,n.knots=5,kappa=c(0.01,2),method.GH=&quot;Pseudo-adaptive&quot;)"/>                                     | <img src="blue_x.png"  title="multivPenal(Surv(TIME0,TIME1,INDICREC)~cluster(PATIENT)+v1+v2+event2(INDICMETA)+terminal(INDICDEATH),formula.Event2=~v1+v2+v3,formula.terminalEvent=~v1,data=dataMultiv,n.knots=c(8,8,8,kappa=c(1,1,1),initialize=FALSE)"/>                       | <img src="blue_x.png"  title="GenfrailtyPenal(Surv(t.start,t.stop,event)~cluster(id)+sex+dukes+charlson+terminal(death),formula.terminalEvent=~sex+dukes+charlson,data=readmission,n.knots=10,kappa=c(9.55e9,1.41e12),recurrentAG=TRUE)"/>                                      |                                       |                                      |     <img src="blue_x.png"  title="GenfrailtyPenal(Surv(t.start,t.stop,event)~cluster(id)+sex+dukes+charlson,data=readmission,family='PH',n.knots=6,kappa=1e5,recurrentAG=TRUE)"/>       |  <img src="blue_x.png"  title="GenfrailtyPenal(Surv(t.start,t.stop,event)~cluster(id)+sex+dukes+charlson+terminal(death),formula.terminalEvent=~sex+dukes+charlson,data=readmission,family=c('PH','PH'),n.knots=10,kappa=c(9.55e9,1.41e12),recurrentAG=TRUE)"/>  |     |    | 
| Weibull                                         | <img src="blue_x.png" title="frailtyPenal(Surv(time,status)~sex+age,data=kidney,hazard=&quot;Weibull&quot;)"/>                       | <img src="blue_x.png" title="frailtyPenal(Surv(time,status) ~ cluster(id)+sex+age,data=kidney,hazard=&quot;Weibull&quot;)"/>                       | <img src="blue_x.png"  title="frailtyPenal(Surv(t1,t2,event)~cluster(group)+subcluster(subgroup)+cov1+cov2,data=dataNested,hazard=&quot;Weibull&quot;)"/>                       | <img src="blue_x.png"  title="additivePenal(Surv(t1,t2,event)~cluster(group)+var1+var2+slope(var1),correlation=FALSE,data=dataAdditive,hazard=&quot;Weibull&quot;)"/>                       |  <img src="blue_x.png"  title="frailtyPenal(Surv(time,event)~cluster(id)+dukes+charlson+sex+chemo+terminal(death),formula.terminalEvent=~dukes+charlson+sex+chemo,data=readmission,hazard=&quot;Weibull&quot;)"/>                       |  <img src="blue_x.png"  title="frailtyPenal(Surv(time,event)~cluster(group)+num.id(id)+dukes+charlson+sex+chemo+terminal(death),formula.terminalEvent=~dukes+charlson+sex+chemo,data=readmission2,recurrentAG=FALSE,hazard=&quot;Weibull&quot;)"/>                       |                                       | <img src="blue_x.png"  title="frailtyPenal(Surv(t.start,t.stop,event)~subcluster(id)+cluster(group)+dukes+terminal(death),formula.terminalEvent=~dukes,hazard=('Weibull'),data=readmissionNested,recurrentAG=TRUE,initialize=FALSE)"/>                      | <img src="blue_x.png"  title="longiPenal(Surv(time1,state)~age+treatment+who.PS+prev.resection,tumor.size~year*treatment+age+who.PS,colorectalSurv,data.Longi=colorectalLongi,random=c(&quot;1&quot;,&quot;year&quot;),id=&quot;id&quot;,link=&quot;Current-level&quot;,left.censoring=-3.33,hazard=&quot;Weibull&quot;)"/>                            | <img src="blue_x.png"  title="trivPenal(Surv(gap.time,new.lesions)~cluster(id)+age+treatment+who.PS+prev.resection+terminal(state),formula.terminalEvent=~age+treatment+who.PS+prev.resection,tumor.size~year*treatment+age+who.PS,data=colorectal,data.Longi=colorectalLongi,random=c(&quot;1&quot;,&quot;year&quot;),id=&quot;id&quot;,link=&quot;Random-effects&quot;,left.censoring=-3.33,recurrentAG=FALSE,hazard=&quot;Weibull&quot;,method.GH=&quot;Pseudo-adaptive&quot;,n.nodes=7)"/>                       |  <img src="blue_x.png"  title="trivPenalNL(Surv(time0,time1,new.lesions)~cluster(id)+age+treatment+terminal(state),formula.terminalEvent=~age+treatment,biomarker=&quot;tumor.size&quot;,formula.KG~1,formula.KD~treatment,dose=&quot;dose&quot;,time.biomarker=&quot;year&quot;,data=colorectal,data.Longi=colorectalLongi,random=&quot;KG&quot;,id=&quot;id&quot;,recurrentAG=TRUE,n.knots=5,kappa=c(0.01,2),method.GH=&quot;Pseudo-adaptive&quot;,hazard=&quot;Weibull&quot;)"/>                                     | <img src="blue_x.png"  title="multivPenal(Surv(TIMEGAP,INDICREC)~cluster(PATIENT)+v1+v2+event2(INDICMETA)+terminal(INDICDEATH),formula.Event2=~v1+v2+v3,formula.terminalEvent=~v1,data=dataMultiv,hazard=&quot;Weibull&quot;)"/>                       |                                       |                                       |                                      |    <img src="blue_x.png"  title="GenfrailtyPenal(Surv(futime,status)~trt,data=adult.retino,hazard='parametric',family='PH')"/>      | <img src="blue_x.png"  title="GenfrailtyPenal(Surv(t.start,t.stop,event)~cluster(id)+terminal(death)+sex+dukes+chemo,~sex+dukes+chemo,data=readmission,recurrentAG=TRUE,hazard='parametric',family=c('PH','PH'))"/>   | <img src="blue_x.png" title="frailtyIllnessDeath(formula = Surv(r,dementia) ~ gender+certif, formula.terminalEvent = Surv(e,t,death) ~ gender+certif  , data=IDPaq1000,print.info = FALSE)"/> | <img src="blue_x.png" title="frailtyCmprsk(formula = Surv(Age,observed_time,Status) ~ Sex,formula2 = ~ Sex  ,data=CPRSKbmtcrr,print.info = FALSE,maxit=100)"/>|  
| Log-logistic, log-normal                        |                                       |                                       |                                       |                                       |                                        |                                        |                                       |                                      |                                            |                                       |                                       |                                       |                                       |                                       |                                       |    <img src="blue_x.png"  title="GenfrailtyPenal(Surv(futime,status)~trt,data=adult.retino,hazard='parametric',family='PO')"/>      | <img src="blue_x.png"  title="GenfrailtyPenal(Surv(t.start,t.stop,event)~cluster(id)+terminal(death)+sex+dukes+chemo,~sex+dukes+chemo,data=readmission,recurrentAG=TRUE,hazard='parametric',family=c('probit','probit'))"/>   |  |  |
| Piecewise                                       | <img src="blue_x.png"  title="frailtyPenal(Surv(t.start,t.stop,event)~sex+dukes+charlson,data=readmission,hazard=&quot;Piecewise-equi&quot;,nb.int=6)"/>  | <img src="blue_x.png"  title="frailtyPenal(Surv(t.start,t.stop,event)~cluster(id)+sex+dukes+charlson,data=readmission,hazard=&quot;Piecewise-per&quot;,nb.int=6)"/>                       | <img src="blue_x.png"  title="frailtyPenal(Surv(t1,t2,event)~cluster(group)+subcluster(subgroup)+cov1+cov2,data=dataNested,hazard=&quot;Piecewise-per&quot;,nb.int=6)"/>                       | <img src="blue_x.png"  title="additivePenal(Surv(t1,t2,event)~cluster(group)+var1+var2+slope(var1),correlation=FALSE,data=dataAdditive,hazard=&quot;Piecewise-per&quot;,nb.int=6)"/>                       |  <img src="blue_x.png"  title="frailtyPenal(Surv(time,event)~cluster(id)+dukes+charlson+sex+chemo+terminal(death),formula.terminalEvent=~dukes+charlson+sex+chemo,data=readmission,hazard=&quot;Piecewise-equi&quot;,nb.int=c(2,4))"/>                       |  <img src="blue_x.png"  title="Text "/>                       |                                       |                                      |                                            |                                       |                                       | <img src="blue_x.png"  title="multivPenal(Surv(TIMEGAP,INDICREC)~cluster(PATIENT)+v1+v2+event2(INDICMETA)+terminal(INDICDEATH),formula.Event2=~v1+v2+v3,formula.terminalEvent=~v1,data=dataMultiv,hazard=&quot;Piecewise-per&quot;,nb.int=c(6,6,6)) "/>                       |                                       |                                       |                                      |          |    |   |  | 
| Sample size calculation & power analysis        |                                       | <img src="blue_x.png"/>               | <img src="blue_x.png"/>               |                                       | <img src="blue_x.png"/>                |                                        | <img src="blue_x.png"/>               |                                      |                                            |                                       |                                       |                                       |                                       |                                       |                                       |                                       |                                       |                                       |                                       |
|     `Available output`                          |                                       |                                       |                                       |                                       |                                        |                                        |                                       |                                      |                                            |                                       |                                       |                                       |                                       |                                      |         |    |                                       |                                       |  
| Predicted frailties                             |                                       | <img src="blue_x.png"  title="fit$frailty.pred"/>                       | <img src="blue_x.png"  title="fit$frailty.pred.group fit$frailty.pred.subgroup"/>                       | <img src="blue_x.png"  title="fit$frailty.pred fit$frailty.pred2"/>                       |  <img src="blue_x.png"  title="fit$frailty.pred"/>                       |                                        |                                       | <img src="blue_x.png"  title="fit$frailty.pred fit$frailty.fam.pred"/>                      | <img src="blue_x.png"/>                            | <img src="blue_x.png"  title="fit$frailty.pred"/>                       |                                       |                                       |                                       |                                       |                                      |            |    |  <img src="blue_x.png"  title="fit$frailty.pred"/>|  <img src="blue_x.png"  title="fit$frailty.pred"/>                       |    
| Variances of the frailties                      |                                       | <img src="blue_x.png"  title="fit$frailty.var"/>                       |                                       |                                       |                                        |                                        |                                       |                                      |                                            |                                       |                                       |                                       |  <img src="blue_x.png"  title="Text "/>                                     |                                       |                                      |         |    | <img src="blue_x.png"  title="Text "/>                                     | <img src="blue_x.png"  title="Text "/>                                     |  
| Martingale residuals                            | <img src="blue_x.png"  title="fit$martingaleCox"/>                       | <img src="blue_x.png"  title="fit$martingale.res"/>                       | <img src="blue_x.png"  title="fit$martingale.res"/>                       | <img src="blue_x.png"  title="fit$martingale.res "/>                       |  <img src="blue_x.png"  title="fit$martingale.res fit$martingaledeath.res"/>                       |                                        |                                       | <img src="blue_x.png"  title="fit$martingale.res fit$martingaledeath.res"/>                      | <img src="blue_x.png"  title="fit$martingaledeath.res "/>                            | <img src="blue_x.png"  title="fit$martingale.res fit$martingaledeath.res"/>                       |                                       |                                       |                                       |                                       |                                      |         |    |                                       |                                       |  
|     `Prediction methods `                       |                                       |                                       |                                       |                                       |                                        |                                        |                                       |                                       |                                      |                                            |                                       |                                       |                       |    |                                       |                                       |                    
| Marginal prediction of a terminal event         | <img src="blue_x.png"  title="#-- prediction of death for two patients between 100 and 100+w, with w in (50,100,...,1900) : prediction(cox.fit,datapred,t=100,window=seq(50,1900,50))"/>                       | <img src="blue_x.png"  title="prediction(shared.fit,datapred,t=100,window=seq(50,1900,50))"/>                       |                                       |                                       |  <img src="blue_x.png"  title="#-- prediction of death between 100 and 100+w given relapses (with confidence intervals) : prediction(joint.fit,datapred,t=100,window=seq(50,1500,50),event=&quot;Terminal&quot;,MC.sample=100)"/>                       |                                        |                                       | <img src="blue_x.png"  title="#-- Compute prediction over the individuals 274 and 4 : prediction(JointNested.fit,data=DataPred,t=500,window=seq(100,1500,200),conditional=FALSE,individual=c(274,4))"/>                      | <img src="blue_x.png"  title="#-- prediction of death between 1 year and 1+2 given history of the biomarker : prediction(JointLongi.fit,datapredj,datapredj_longi,t=1,window=2)"/>                            | <img src="blue_x.png"  title="#-- prediction of death between 1 year and 1+w : prediction(trivPenal.fit,datapredj,datapredj_longi,t=1,window=seq(0.5,2.5,0.2),MC.sample=100)"/>                       | <img src="blue_x.png" title="#-- prediction of death between t and t+0.5 : prediction(trivPenalNL.fit,datapredj,datapredj_longi,t=seq(2,3,0.2),window=0.5,MC.sample=100)"/>                                       |                                       |                                       |                                       |                                      |                  |    |                                       |                                       |                              
| Conditional prediction of a terminal event      | <img src="blue_x.png"/>                       | <img src="blue_x.png"  title="prediction(shared.fit,datapred,t=100,window=seq(50,1900,50),conditional=TRUE)"/>                       |                                       |                                       |                                        |                                        |                                       |                                      |                                            |                                       |                                       |                                       |                                       |                                       |                                      |                |    |                                       |                                       |                     | Marginal prediction of a new recurrent event    | 			                          | <img src="blue_x.png"  title="prediction(shared.fit,datapred,t=200,window=seq(50,1900,50),event=&quot;Recurrent&quot;,MC.sample=100)"/>                       |                                       |                                       |  <img src="blue_x.png"  title="#-- prediction of death between 100 and 100+w given relapses (with confidence intervals) : prediction(joint.fit,datapred,t=100,window=seq(50,1500,50),event=&quot;Recurrent&quot;,MC.sample=100)"/>                       |                                        |                                       |                                      | 			                                |                                       | 		                                |                                       |                                       |                                       |                                      |               |    |                                       |                                       |                            
|Conditional prediction of a new recurrent event | 			                          | <img src="blue_x.png"  title="prediction(shared.fit,datapred,t=200,window=seq(50,1900,50),event=&quot;Recurrent&quot;,conditional=TRUE,MC.sample=100)"/>                       |                                       |                                       |                                        |                                        |                                       |                                       |                                      | 			                                | 		                                |                                       |                                       |                                       |                                      |               |    |                                       |                                       |    |`Model evaluation `                         |                                       |                                       |                                       |                                       |                                       |                                       |                                        |                                        |                                       |                                      |                                            |                                       |                                       |                                       |                                      |               |    |                                       |                                       |                        
|Cmeasures                                       | <img src="blue_x.png"  title="Cmeasures(fit)"/>|                              |                                       |                                       |                                       |                                        |                                        |                                       |                                      |                                            |                                       |                                       |                                       |                                       |                                      |         |    |                                       |                                       |  
| Epoce                                           |                                       |                                       |                                       |                                       |  <img src="blue_x.png"  title="epoce(fit,time=c(1,1.5, 2, 2.5))"/>                       |                                        |                                       |                                      | <img src="blue_x.png"  title="epoce(fit,time=c(1,1.5, 2, 2.5))"/>                            | <img src="blue_x.png"  title="epoce(fit,time=c(1,1.5, 2, 2.5))"/>                       |                                       |                                       |                                       |                                       |                                      |         |    |    |    |  
|     `Model structure `                          |                                       |                                       |                                       |                                       |                                       |                                       |                                        |                                        |                                       |                                      |                                            |                                       |                                       |                                       |                                      |          |    |                                       |                                       |  
| STE                                             |                                       |                                       |                                       |                                       |                                        |                                        |                                       |                                      |                                            |                                       |                                       |                                       |  ![](blue_x.png)                       |                                      |                                       |         |    |                                       |                                       |  
| Prediction of treatment effects                 |                                       |                                       |                                       |                                       |                                        |                                        |                                       |                                      |                                            |                                       |                                       |                                       |  ![](blue_x.png)                       | <img src="blue_x.png"/>                                       |  <img src="blue_x.png"/>                                     |         |    |    |    |  
| Statistical model                               | <img src="blue_x.png"/>                | <img src="blue_x.png"/>                | <img src="blue_x.png"/>                | <img src="blue_x.png"/>                       |<img src="blue_x.png"/>                       |<img src="blue_x.png"/>                       |<img src="blue_x.png"/>                       |<img src="blue_x.png"/>                       |<img src="blue_x.png"/>                       |<img src="blue_x.png"/>                       |                      |  <img src="blue_x.png"/>                      |<img src="blue_x.png"/>                       |   <img src="blue_x.png"/>                                     |   <img src="blue_x.png"/>                                    |    <img src="blue_x.png"/>     |  <img src="blue_x.png"/>  |  <img src="blue_x.png"/>  |  <img src="blue_x.png"/>  |  
| Mechanistic model (ODE)                         |                                       |                                       |                                       |                                       |                                       |                                       |                                        |                                        |                                       |                                      | <img src="blue_x.png"/>                                           |                                      |                                       |                                       |                                      |        |    |    |    |
| Mediation analysis                              |                                       |                          | | | | | | | | |  | | <img src="blue_x.png"/> | | | | | | |
Table 1: Package characteristics. Blue cross is for option available for a given type of model in the package on CRAN, orange cross is for option included in the package but not on CRAN yet. Empty cells mean that an option is not available for a given type of model (either not coded yet or simply not applicable). RE = Recurrent Event; TE = Terminal Event; LO = Longitudinal Outcome; STE = Surrogate threshold effect; ODE = Ordinary Differential Equation; GSM = Generalized Survival Model; PHM = Proportional Hazards Model; AHM = Additive Hazards Model; POM = Proportional Odds Model; PROM = Probit Model.

#### Reference
Agnieszka Krol, Audrey Mauguen, Yassin Mazroui, Alexandre Laurent, Stefan Michiels, Virginie Rondeau (2017), [Tutorial in Joint Modeling and Prediction: A Statistical Software for Correlated Longitudinal Outcomes, Recurrent Events and a Terminal Event.](https://www.jstatsoft.org/article/view/v081i03)
*Journal of Statistical Software*, **81**.

Casimir Ledoux Sofeu and Virginie Rondeau (2020). [How to use frailtypack for validating failure-time surrogate endpoints using individual patient data from meta-analyses of randomized controlled trials.] (https://doi.org/10.1371/journal.pone.0228098) *PLOS ONE*, **15**, 1-25.

#### Shiny
A shiny application of frailtypack is available, allowing modelisation and prediction of several models presents in frailtypack, at https://frailtypack-pkg.shinyapps.io/shiny_frailtypack/
This application can be run in a local mode in R thanks to the function runShiny().

##### Note 
If you want to take in charge frailtypack as a project, but work on a macOSX with a version of R >= 3.6, a problem must happen between openmp and clang. clang does not seem to support option '-fopenmp'.
To avoid this, you should edit your personal Makevars (~/.R/Makevars), admitting you use gfortran, by relocating 
CC=clang by CC=gfortran

